import { ZodError, ZodIssue } from "zod";
import { ErrorCodes, ProgrammerErrors } from "./ErrorCodes";
export declare type ODErrorConstructorParameters = {
    code: ErrorCodes;
    additionalData?: {};
} & Omit<Error, "name">;
export declare class ODError extends Error {
    readonly code: ErrorCodes;
    readonly timestamp?: number;
    readonly additionalData?: {};
    constructor({ code, additionalData, message }: ODErrorConstructorParameters);
}
export declare type ODProgrammerErrorConstructorParameters = Omit<ODErrorConstructorParameters, "code"> & {
    link?: string;
    code: ProgrammerErrors;
};
export declare class ODProgrammerError extends ODError {
    link?: string;
    constructor({ link, ...args }: ODProgrammerErrorConstructorParameters);
}
export declare type ODValidationErrorConstructorParameters = ODErrorConstructorParameters & {
    zodError?: ZodError;
};
export declare class ODValidationError extends ODError {
    issues?: ZodIssue[];
    constructor({ zodError, ...args }: ODValidationErrorConstructorParameters);
}
