import { z } from "zod";
import { createAnswer, createChildNode, createCondition, createEdge, createInput, createNode } from "../creators";
import { getCondition, getConditions, getEdge, getInput, getInputs, getNode, getTree, getNodeNames } from "../getters";
import { addCondition, addEdge, addInput, addInputAnswer, addNode, createAndAddCondition, createAndAddEdge, createAndAddInput, createAndAddNode, deleteConditions, deleteEdges, deleteInputAnswer, deleteInputs, deleteNodes, relateConditionToNode, relateInputToCondition, relateInputToNode, removeInputFromNode, updateEdgeTarget, updateInputAnswer, updateInputAnswerOrder, updateNodeContent, updateNodeName, updateNodePosition, updateStartNode } from "../mutaters";
import { isValidEdge } from "../validators";
export declare const Type: z.ZodObject<{
    startNode: z.ZodOptional<z.ZodString>;
    nodes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        id: z.ZodString;
        position: z.ZodObject<{
            x: z.ZodNumber;
            y: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            x: number;
            y: number;
        }, {
            x: number;
            y: number;
        }>;
        type: z.ZodLiteral<"customNode">;
        data: z.ZodObject<{
            name: z.ZodOptional<z.ZodString>;
            content: z.ZodAny;
            inputs: z.ZodArray<z.ZodString, "many">;
            conditions: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        }, {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        }>;
    }, "strip", z.ZodTypeAny, {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    }, {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    }>>>;
    edges: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        id: z.ZodString;
        source: z.ZodString;
        target: z.ZodString;
        type: z.ZodEnum<["default"]>;
        conditionId: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }, {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }>>>;
    inputs: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        id: z.ZodString;
        type: z.ZodEnum<["select"]>;
        answers: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            text: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            text: string;
        }, {
            id: string;
            text: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }, {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }>>>;
    conditions: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        type: z.ZodEnum<["select"]>;
        id: z.ZodString;
        inputId: z.ZodString;
        answerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }, {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }>>>;
}, "strip", z.ZodTypeAny, {
    inputs?: Record<string, {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }> | undefined;
    conditions?: Record<string, {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }> | undefined;
    startNode?: string | undefined;
    nodes?: Record<string, {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    }> | undefined;
    edges?: Record<string, {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }> | undefined;
}, {
    inputs?: Record<string, {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }> | undefined;
    conditions?: Record<string, {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }> | undefined;
    startNode?: string | undefined;
    nodes?: Record<string, {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    }> | undefined;
    edges?: Record<string, {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }> | undefined;
}>;
export declare function createTreeMethods(tree: TTree): {
    addCondition: (condition: {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }) => void;
    addEdge: (edge: {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }) => void;
    addInput: (input: {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }) => void;
    addInputAnswer: (inputId: string, answer: {
        id: string;
        text: string;
    }) => void;
    addInputToCondition: (conditionId: string, inputId: string) => Error | undefined;
    addNode: (node: {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    }) => void;
    createAndAddCondition: (condition: import("../creators").NewConditionData) => void;
    createAndAddEdge: (edge: import("../creators").NewEdgeData) => void | Error;
    createAndAddInput: (input?: import("../creators").NewInputData | undefined) => void;
    createAndAddNode: (node: import("../creators").NewNodeData) => void;
    createAnswer: (answer: import("../creators").NewAnswerData) => {
        text: string;
        id: string;
    };
    createChildNode: (nodeId: string, newNode: import("../creators").NewNodeData) => Error | {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    };
    createCondition: typeof createCondition;
    createEdge: (edge: import("../creators").NewEdgeData) => Error | {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    };
    createInput: typeof createInput;
    createNode: typeof createNode;
    deleteConditions: (ids: string[]) => void;
    deleteEdges: (ids: string[]) => void;
    deleteInputAnswer: (inputId: string, answerId: string) => void;
    deleteInputs: (ids: string[]) => void;
    deleteNodes: (ids: string[]) => void;
    getChildren: (nodeId: string) => string[];
    getCondition: (conditionId: string) => {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    } | undefined;
    getConditions: (conditionIds: string[]) => Record<string, {
        type: "select";
        id: string;
        inputId: string;
        answerId: string;
    }> | undefined;
    getConnectableNodes: (nodeId: string) => string[];
    getEdge: (edgeId: string) => {
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    } | undefined;
    getInput: (inputId: string) => {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    } | undefined;
    getInputs: (inputIds: string[]) => Record<string, {
        type: "select";
        id: string;
        answers: {
            id: string;
            text: string;
        }[];
    }> | undefined;
    getNode: (nodeId: string) => {
        type: "customNode";
        data: {
            name?: string | undefined;
            content?: any;
            inputs: string[];
            conditions: string[];
        };
        id: string;
        position: {
            x: number;
            y: number;
        };
    } | undefined;
    getNodeNames: (ids?: string[] | undefined) => {
        id: string;
        name: string;
    }[];
    getParents: (nodeId: string) => string[];
    getPaths: (nodeId: string) => string[][];
    getTree: () => {
        inputs?: Record<string, {
            type: "select";
            id: string;
            answers: {
                id: string;
                text: string;
            }[];
        }> | undefined;
        conditions?: Record<string, {
            type: "select";
            id: string;
            inputId: string;
            answerId: string;
        }> | undefined;
        startNode?: string | undefined;
        nodes?: Record<string, {
            type: "customNode";
            data: {
                name?: string | undefined;
                content?: any;
                inputs: string[];
                conditions: string[];
            };
            id: string;
            position: {
                x: number;
                y: number;
            };
        }> | undefined;
        edges?: Record<string, {
            conditionId?: string | undefined;
            type: "default";
            id: string;
            source: string;
            target: string;
        }> | undefined;
    };
    isCircular: ({ source, target }: {
        source: string;
        target: string;
    }) => boolean;
    isValidEdge: ({ source, target }: Omit<{
        conditionId?: string | undefined;
        type: "default";
        id: string;
        source: string;
        target: string;
    }, "id">) => true | Error;
    relateConditionToNode: (nodeId: string, conditionId: string) => Error | undefined;
    relateInputToNode: (nodeId: string, inputId: string) => Error | undefined;
    removeInputFromNode: (nodeId: string, inputId: string) => Error | undefined;
    updateEdgeTarget: (edgeId: string, newTarget: string) => void;
    updateInputAnswer: (inputId: string, answerId: string, newAnswer: string) => void;
    updateInputAnswerOrder: (inputId: string, newAnswers: {
        id: string;
        text: string;
    }[]) => void;
    updateNodeContent: (nodeId: string, content: any) => void;
    updateNodeName: (nodeId: string, name: string) => void;
    updateNodePosition: (nodeId: string, position: {
        x: number;
        y: number;
    }) => void;
    updateStartNode: (startNode: string) => Error | undefined;
};
export { addCondition, addEdge, addInput, addInputAnswer, addNode, createAndAddCondition, createAndAddEdge, createAndAddInput, createAndAddNode, createAnswer, createChildNode, createCondition, createEdge, createInput, createNode, deleteConditions, deleteEdges, deleteInputAnswer, deleteInputs, deleteNodes, getCondition, getConditions, getEdge, getInput, getInputs, getNode, getNodeNames, getTree, isValidEdge, relateConditionToNode, relateInputToCondition, relateInputToNode, removeInputFromNode, updateEdgeTarget, updateInputAnswer, updateInputAnswerOrder, updateNodeContent, updateNodeName, updateNodePosition, updateStartNode, };
export declare type TTree = z.infer<typeof Type>;
